@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2004 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-src/portage/bin/ebuild.sh,v 1.201.2.24 2005/02/26 11:22:37 carpaski Exp $
+# $Header: /var/cvsroot/gentoo-src/portage/bin/ebuild.sh,v 1.201.2.25 2005/04/20 15:19:03 jstubbs Exp $
 
 export SANDBOX_PREDICT="${SANDBOX_PREDICT}:/proc/self/maps:/dev/console:/usr/lib/portage/pym:/dev/random"
 export SANDBOX_WRITE="${SANDBOX_WRITE}:/dev/shm:${PORTAGE_TMPDIR}"
@@ -621,25 +621,6 @@ END
 
 dyn_setup()
 {
-	if [ "$USERLAND" == "Linux" ]; then	
-		# The next bit is to ease the broken pkg_postrm()'s
-		# some of the gcc ebuilds have that nuke the new
-		# /lib/cpp and /usr/bin/cc wrappers ...
-	
-		# Make sure we can have it disabled somehow ....
-		if [ "${DISABLE_GEN_GCC_WRAPPERS}" != "yes" ]; then
-			# Create /lib/cpp if missing or a symlink
-			if [ -L /lib/cpp -o ! -e /lib/cpp ]; then
-				[ -L /lib/cpp ] && rm -f /lib/cpp
-				gen_wrapper /lib/cpp cpp
-			fi
-			# Create /usr/bin/cc if missing for a symlink
-			if [ -L /usr/bin/cc -o ! -e /usr/bin/cc ]; then
-				[ -L /usr/bin/cc ] && rm -f /usr/bin/cc
-				gen_wrapper /usr/bin/cc gcc
-			fi
-		fi
-	fi
 	pkg_setup
 }
 
