@@ -1,8 +1,8 @@
 # archive_conf.py -- functionality common to archive-conf and dispatch-conf
 # Copyright 2003-2004 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-src/portage/pym/dispatch_conf.py,v 1.3.2.1 2005/01/16 02:35:33 carpaski Exp $
-cvs_id_string="$Id: dispatch_conf.py,v 1.3.2.1 2005/01/16 02:35:33 carpaski Exp $"[5:-2]
+# $Header: /var/cvsroot/gentoo-src/portage/pym/dispatch_conf.py,v 1.3.2.2 2005/04/17 09:01:55 jstubbs Exp $
+cvs_id_string="$Id: dispatch_conf.py,v 1.3.2.2 2005/04/17 09:01:55 jstubbs Exp $"[5:-2]
 
 # Library by Wayne Davison <gentoo@blorf.net>, derived from code
 # written by Jeremy Wohl (http://igmus.org)
@@ -35,7 +35,9 @@ def read_config(mandatory_opts):
         if not opts.has_key(key):
             print >> sys.stderr, 'dispatch-conf: Missing option "%s" in /etc/dispatch-conf.conf; fatal' % (key,)
 
-    if not (os.path.exists(opts['archive-dir']) and os.path.isdir(opts['archive-dir'])):
+    if not os.path.exists(opts['archive-dir']):
+        os.mkdir(opts['archive-dir'])
+    elif not os.path.isdir(opts['archive-dir']):
         print >> sys.stderr, 'dispatch-conf: Config archive dir [%s] must exist; fatal' % (opts['archive-dir'],)
         sys.exit(1)
 
@@ -63,6 +65,7 @@ def rcs_archive(archive, curconf, newconf, mrgconf):
         os.system(RCS_LOCK + ' ' + archive)
     os.system(RCS_PUT + ' ' + archive)
 
+    ret = 0
     if newconf != '':
         os.system(RCS_GET + ' -r' + RCS_BRANCH + ' ' + archive)
         has_branch = os.path.exists(archive)
@@ -78,11 +81,12 @@ def rcs_archive(archive, curconf, newconf, mrgconf):
         if has_branch:
             if mrgconf != '':
                 # This puts the results of the merge into mrgconf.
-                os.system(RCS_MERGE % (archive, mrgconf))
+                ret = os.system(RCS_MERGE % (archive, mrgconf))
                 mystat = os.lstat(newconf)
                 os.chmod(mrgconf, mystat[ST_MODE])
                 os.chown(mrgconf, mystat[ST_UID], mystat[ST_GID])
         os.rename(archive, archive + '.dist.new')
+    return ret
 
 
 def file_archive(archive, curconf, newconf, mrgconf):
@@ -125,13 +129,16 @@ def file_archive(archive, curconf, newconf, mrgconf):
             print >> sys.stderr, 'dispatch-conf: Error copying %s to %s: %s; fatal' % \
                   (newconf, archive + '.dist.new', str(why))
 
+        ret = 0
         if mrgconf != '' and os.path.exists(archive + '.dist'):
             # This puts the results of the merge into mrgconf.
-            os.system(DIFF3_MERGE % (curconf, archive + '.dist', newconf, mrgconf))
+            ret = os.system(DIFF3_MERGE % (curconf, archive + '.dist', newconf, mrgconf))
             mystat = os.lstat(newconf)
             os.chmod(mrgconf, mystat[ST_MODE])
             os.chown(mrgconf, mystat[ST_UID], mystat[ST_GID])
 
+        return ret
+
 
 def rcs_archive_post_process(archive):
     """Check in the archive file with the .dist.new suffix on the branch
